@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ PluginUtilTest::PluginUtilTest(QObject *parent)
 {
 }
 
-PluginUtilTest::~PluginUtilTest()
-{
-}
+PluginUtilTest::~PluginUtilTest() = default;
 
 void PluginUtilTest::shouldTestIsEnabled_data()
 {
@@ -25,24 +23,20 @@ void PluginUtilTest::shouldTestIsEnabled_data()
     QTest::addColumn<QString>("pluginId");
     QTest::addColumn<bool>("result");
 
-    //Use default value
+    // Use default value
     QTest::newRow("emptysettings") << QStringList() << QStringList() << true << QStringLiteral("foo") << true;
     QTest::newRow("emptysettings-2") << QStringList() << QStringList() << false << QStringLiteral("foo") << false;
 
-    //Return false each time that pluginid is empty
+    // Return false each time that pluginid is empty
     QTest::newRow("pluginidempty") << QStringList() << QStringList() << true << QString() << false;
     QTest::newRow("pluginidempty-2") << QStringList() << QStringList() << false << QString() << false;
 
-    //Use setting from user settings
-    QStringList disabled{
-        QStringLiteral("foo")
-    };
+    // Use setting from user settings
+    QStringList disabled{QStringLiteral("foo")};
     QTest::newRow("usersettingdisabled") << QStringList() << disabled << true << QStringLiteral("foo") << false;
     QTest::newRow("usersettingdisabled-2") << QStringList() << disabled << false << QStringLiteral("foo") << false;
 
-    QStringList enabled{
-        QStringLiteral("foo")
-    };
+    QStringList enabled{QStringLiteral("foo")};
     QTest::newRow("usersettingenabled") << enabled << QStringList() << true << QStringLiteral("foo") << true;
     QTest::newRow("usersettingenabled-2") << enabled << QStringList() << false << QStringLiteral("foo") << true;
 }
