@@ -1,14 +1,14 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TEMPLATEMANAGER_H
-#define TEMPLATEMANAGER_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <QObject>
+#include <memory>
 
 namespace PimCommon
 {
@@ -41,8 +41,6 @@ private:
     void initTemplatesDirectories(const QString &templatesRelativePath);
     TemplateInfo loadTemplate(const QString &themePath, const QString &defaultDesktopFileName);
 
-    TemplateManagerPrivate *const d;
+    std::unique_ptr<TemplateManagerPrivate> const d;
 };
 }
-
-#endif // TEMPLATEMANAGER_H
