@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -13,9 +13,7 @@ BalooCompletionEmailTest::BalooCompletionEmailTest(QObject *parent)
 {
 }
 
-BalooCompletionEmailTest::~BalooCompletionEmailTest()
-{
-}
+BalooCompletionEmailTest::~BalooCompletionEmailTest() = default;
 
 void BalooCompletionEmailTest::returnEmptyListWhenEmailListIsEmpty()
 {
