@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -162,7 +162,7 @@ void BlackListBalooEmailCompletionWidget::slotSelectEmails()
 
 void BlackListBalooEmailCompletionWidget::slotSearchLineEditChanged(const QString &text)
 {
-    mSearchButton->setEnabled(text.trimmed().count() > 2);
+    mSearchButton->setEnabled(text.trimmed().length() > 2);
     hideMoreResultAndChangeLimit();
 }
 
