@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -34,7 +34,7 @@ public:
     void setPluginName(const QString &name);
     void setPluginDirectory(const QString &name);
     void initializePlugins();
-    virtual void initializeInterfaceRequires(AbstractGenericPluginInterface *interface);
+    virtual bool initializeInterfaceRequires(AbstractGenericPluginInterface *interface);
     static QString actionXmlExtension(PimCommon::ActionType::Type type);
 
     void initializePluginActions(const QString &prefix, KXMLGUIClient *guiClient);
